@@ -94,6 +94,7 @@ if (debug >= level) info("[%s:%d] " fmt, __PRETTY_FUNCTION__, __LINE__ , ## args
 #define BRIDGE_MR97311 17
 #define BRIDGE_PAC207 18
 #define BRIDGE_VC032X 19
+#define BRIDGE_PAC7311 20
 
 #define SENSOR_SAA7113 0
 #define SENSOR_INTERNAL 1
@@ -121,6 +122,7 @@ if (debug >= level) info("[%s:%d] " fmt, __PRETTY_FUNCTION__, __LINE__ , ## args
 #define SENSOR_MO4000 23
 #define SENSOR_OV7660 24
 #define SENSOR_PO3130NC 25
+#define SENSOR_PAC7311 26
 
 /* Alternate interface transfer sizes */
 #define SPCA50X_ALT_SIZE_0       0
@@ -169,6 +171,7 @@ enum {
 	S561,			// Sunplus Compressed stream
 	PGBRG,			// Pixart RGGB bayer
 	YUY2, // YUYV packed
+    PJPG, // Pixart jpeg used with PAC7311
 };
 enum { QCIF = 1,
 	QSIF,
